==> haskell-hslua-module-zip-1.1.2-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.2
visibility:           public
id:                   hslua-module-zip-1.1.2-H3EsQ78qV5y62VA5OStxvX
key:                  hslua-module-zip-1.1.2-H3EsQ78qV5y62VA5OStxvX
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  c77b9639a4d038d6b18c41a951c78b64
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.2-H3EsQ78qV5y62VA5OStxvX
depends:
    base-4.17.2.1 bytestring-0.11.5.3 filepath-1.4.2.2
    hslua-core-2.3.1-8UKtW8ALUvCDY9LUMLjR8F
    hslua-list-1.1.3-JJGeN0t8hCZFo2HrVT3BN
    hslua-marshalling-2.3.1-7B3Sre5ByLi7setfeS2P6E
    hslua-packaging-2.3.1-FTZcqYAUUAXLQGWOOaaXmd
    hslua-typing-0.1.1-3cilkW91NRF70LNZBHei1a text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-1ZPjVezok1M1K2ch4ABGcc

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-zip-1.1.2-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.2
visibility:           public
id:                   hslua-module-zip-1.1.2-Jj9ucGkiJ4Y721r7G9eLmP
key:                  hslua-module-zip-1.1.2-Jj9ucGkiJ4Y721r7G9eLmP
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  8b48c4bd7fba73494c435f2d4f39110b
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-zip-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.2-Jj9ucGkiJ4Y721r7G9eLmP
depends:
    base-4.17.2.1 bytestring-0.11.5.3 filepath-1.4.2.2
    hslua-core-2.3.1-54rXN7zYylbDApFlVoB5xw
    hslua-list-1.1.3-HqT4uRzdBxQEWIUX071gkl
    hslua-marshalling-2.3.1-FncQmvmsHr0H9hRnpxXZJ0
    hslua-packaging-2.3.1-K5yVHDAHi3j8CiA9XeLwva
    hslua-typing-0.1.1-1ThvzeLiEyU2Dm0VZg6ugA text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-AsHYNE2Ef3DKxQ61UayGTy

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
